@@ -154,9 +154,9 @@ static void cli_incoming_media_evict_players(str *instr, struct cli_writer *cw,
 HANDLER_START(cli_set_handlers)
 	HANDLER_CMD("maxopenfiles",		cli_incoming_set_maxopenfiles,		"<uint>",				"set the max number of allowed open files")
 	HANDLER_CMD("maxsessions",		cli_incoming_set_maxsessions,		"<int>",				"set the max number of allowed sessions")
-	HANDLER_CMD("maxcpu",			cli_incoming_set_maxcpu,		"<float>",				"set maxmimum CPU usage allowed")
-	HANDLER_CMD("maxload",			cli_incoming_set_maxload,		"<float>",				"set maxmimum load average allowed")
-	HANDLER_CMD("maxbw",			cli_incoming_set_maxbw,			"<uint>",				"set maxmimum bandwidth usage average allowed")
+	HANDLER_CMD("maxcpu",			cli_incoming_set_maxcpu,		"<float>",				"set maximum CPU usage allowed")
+	HANDLER_CMD("maxload",			cli_incoming_set_maxload,		"<float>",				"set maximum load average allowed")
+	HANDLER_CMD("maxbw",			cli_incoming_set_maxbw,			"<uint>",				"set maximum bandwidth usage average allowed")
 	HANDLER_CMD("timeout",			cli_incoming_set_timeout,		"<uint>",				"set the --timeout parameter")
 	HANDLER_CMD("silenttimeout",		cli_incoming_set_silenttimeout,		"<uint>",				"set the --silent-timeout parameter")
 	HANDLER_CMD("offertimeout",		cli_incoming_set_offertimeout,		"<uint>",				"set the --offer-timeout parameter")
@@ -178,9 +178,9 @@ HANDLER_START(cli_list_handlers)
 	HANDLER_CMD("counters",			cli_incoming_list_counters,		NULL,					"print per-second counters")
 	HANDLER_CMD("maxopenfiles",		cli_incoming_list_maxopenfiles,		NULL,					"print the number of allowed open files")
 	HANDLER_CMD("maxsessions",		cli_incoming_list_maxsessions,		NULL,					"print the number of allowed sessions")
-	HANDLER_CMD("maxcpu",			cli_incoming_list_maxcpu,		NULL,					"print maxmimum CPU usage allowed")
-	HANDLER_CMD("maxload",			cli_incoming_list_maxload,		NULL,					"print maxmimum load average allowed")
-	HANDLER_CMD("maxbw",			cli_incoming_list_maxbw	,		NULL,					"print maxmimum bandwidth usage average allowed")
+	HANDLER_CMD("maxcpu",			cli_incoming_list_maxcpu,		NULL,					"print maximum CPU usage allowed")
+	HANDLER_CMD("maxload",			cli_incoming_list_maxload,		NULL,					"print maximum load average allowed")
+	HANDLER_CMD("maxbw",			cli_incoming_list_maxbw	,		NULL,					"print maximum bandwidth usage average allowed")
 	HANDLER_CMD("timeout",			cli_incoming_list_timeout,		NULL,					"print timeout parameter")
 	HANDLER_CMD("silenttimeout",		cli_incoming_list_silenttimeout,	NULL,					"print silent-timeout parameter")
 	HANDLER_CMD("offertimeout",		cli_incoming_list_offertimeout,		NULL,					"print offer-timeout parameter")
