@@ -908,6 +908,12 @@ static bool media_player_cache_entry_init(struct media_player *mp, const rtp_pay
 
 	entry->coder.handler->packet_encoded = media_player_packet_cache;
 
+	call_memory_arena_release();
+	memory_arena = &entry->arena;
+	codec_init_payload_type(&entry->coder.handler->source_pt, MT_UNKNOWN);
+	codec_init_payload_type(&entry->coder.handler->dest_pt, MT_UNKNOWN);
+	call_memory_arena_set(mp->call);
+
 	// use low priority (10 nice)
 	thread_create_detach_prio(media_player_cache_entry_decoder_thread, obj_hold(entry), NULL, 10, "mp decoder");
 
@@ -1275,7 +1281,7 @@ static struct media_player_media_file *media_player_media_file_new(str blob) {
 	__auto_type fo = obj_alloc0(struct media_player_media_file,
 			media_player_media_file_free);
 	fo->blob = blob;
-	fo->blob.dup = call_ref; // string is allocated by reference on `fo`
+	fo->blob.arena = memory_arena; // string is allocated by reference on `fo`
 	RTPE_GAUGE_ADD(media_cache, blob.len);
 	fo->atime_us = fo->mtime_us = rtpe_now;
 	return fo;
